Enum page_hunter::ErrorKind
source · pub enum ErrorKind {
FieldValueError(String),
}Expand description
Provides a way to categorize the pagination error.
Variants
FieldValueError(String)
Raised when a value in a field on the Page is invalid based on the pagination logic.
Implementations
sourceimpl ErrorKind
impl ErrorKind
sourcepub fn is_field_value_error(&self) -> bool
pub fn is_field_value_error(&self) -> bool
Check if the ErrorKind is a ErrorKind::FieldValueError.