Struct page_hunter::Book

source ·
pub struct Book<E> { /* private fields */ }
Model to represent a book of paginated items.

Fields:
  • sheets: Represents the sheets in a Book as a Vec of Page of generic elements E.

Implementations

source

impl<E> Book<E>

source

pub fn get_sheets(&self) -> &Vec<Page<E>>

Get sheets

source

pub fn new(sheets: &Vec<Page<E>>) -> Book<E>
where E: Clone,

Create a new Book instance.

Arguments:
  • sheets: A reference to a collection of Page of items E, where E implements Clone and Debug.
Returns:

A Book of the paginated items E if successful, otherwise a PaginationError is returned.

Example:
use page_hunter::*;

let sheets: Vec<Page<u32>> = vec![
    Page::new(&vec![1, 2], 0, 2, 5).unwrap_or_else(|error| {
        panic!("Error creating page model: {:?}", error);
    }),
    Page::new(&vec![3, 4], 1, 2, 5).unwrap_or_else(|error| {
        panic!("Error creating page model: {:?}", error);
    }),
];

let book: Book<u32> = Book::new(&sheets);